package com.ics.admin.service.meeting;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ics.admin.domain.meeting.Reservation;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ics.admin.domain.meeting.RoomContent;
import com.ics.admin.domain.meeting.vo.MeetingAmountVo;

import java.math.BigDecimal;
import java.util.List;

/**
 * 预约记录Service接口
 * 
 * @author chen
 * @date 2024-02-25
 */
public interface IReservationService extends IService<Reservation> {
    /**
     * 查询预约记录
     * 
     * @param id 预约记录ID
     * @return 预约记录
     */
    Reservation selectReservationById(Long id);

    /**
     * 查询预约记录列表
     * 
     * @param reservation 预约记录
     * @return 预约记录集合
     */
    List<Reservation> selectReservationList(Reservation reservation);

    /**
     * 新增预约记录
     * 
     * @param reservation 预约记录
     * @return 结果
     */
    int insertReservation(Reservation reservation);

    /**
     * 修改预约记录
     * 
     * @param reservation 预约记录
     * @return 结果
     */
    int updateReservation(Reservation reservation);

    /**
     * 批量删除预约记录
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    int deleteReservationByIds(String ids);

    /**
     * 删除预约记录信息
     * 
     * @param id 预约记录ID
     * @return 结果
     */
    int deleteReservationById(Long id);

    boolean selectFreeMeetingRoom(Reservation reservation);

    MeetingAmountVo calculateMeetingRoomAmount(Reservation reservation);

    IPage<Reservation> selectReservationListByUserId(Reservation reservation, Integer pageNum, Integer pageSize);

    Reservation selectByOrderNumber(String outTradeNo);

    void selectTimeByMeetingRoomTime(Reservation reservation);

    List<Reservation> selectByRoomContent(RoomContent roomContent);

    List<Reservation> selectReservationListByDay();

}
