package com.ics.admin.service.meeting;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ics.admin.domain.meeting.Reservation;
import com.ics.admin.domain.meeting.RoomRecord;
import com.ics.admin.domain.meeting.VisitorPerson;
import com.baomidou.mybatisplus.extension.service.IService;
import java.util.List;

/**
 * 预约参观人员Service接口
 * 
 * @author chen
 * @date 2024-02-25
 */
public interface IVisitorPersonService extends IService<VisitorPerson> {
    /**
     * 查询预约参观人员
     * 
     * @param id 预约参观人员ID
     * @return 预约参观人员
     */
    VisitorPerson selectReservationPersonById(Long id);

    /**
     * 查询预约参观人员列表
     * 
     * @param visitorPerson 预约参观人员
     * @return 预约参观人员集合
     */
    List<VisitorPerson> selectReservationPersonList(VisitorPerson visitorPerson);

    /**
     * 新增预约参观人员
     * 
     * @param visitorPerson 预约参观人员
     * @return 结果
     */
    int insertReservationPerson(VisitorPerson visitorPerson);

    /**
     * 修改预约参观人员
     * 
     * @param visitorPerson 预约参观人员
     * @return 结果
     */
    int updateReservationPerson(VisitorPerson visitorPerson);

    /**
     * 批量删除预约参观人员
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    int deleteReservationPersonByIds(String ids);

    /**
     * 删除预约参观人员信息
     * 
     * @param id 预约参观人员ID
     * @return 结果
     */
    int deleteReservationPersonById(Long id);

    IPage<VisitorPerson> selectVisitorRecord(Long userId, Integer pageNum, Integer pageSize);

    IPage<VisitorPerson> selectVisitorRecordByIntervieweeId(Long intervieweeId,Long parkId, Integer pageNum, Integer pageSize);

    int updateVisitorPersonStatus(VisitorPerson person);

    List<RoomRecord> getRecordByReservationId(Long id);

    VisitorPerson selectByUserId(String personId);

}
